@@ -39,7 +39,7 @@ do(Release, State) ->
                         end
                     end
                 ],
-            try beam_lib:strip_release(OutputDir) of
+            try beam_lib:strip_release(OutputDir,["Attr"]) of
                 {ok, _} ->
                     {ok, State1};
                 {error, _, Reason} ->
@@ -663,22 +663,26 @@ include_erts(State, Release, OutputDir, RelDir) ->
                     ok = rlx_file_utils:copy(ErtsBinDir, LocalErtsBin,
                                              [recursive, {file_info, [mode, time]}]),
 
-                    case OsFamily of
+                    Result = case OsFamily of
                         unix ->
                             DynErl = filename:join([LocalErtsBin, "dyn_erl"]),
                             Erl = filename:join([LocalErtsBin, "erl"]),
+                            ok = rlx_file_utils:ensure_writable(Erl),
                             rlx_file_utils:copy(DynErl, Erl);
                         win32 ->
-                            DynErl = filename:join([LocalErtsBin, "dyn_erl.ini"]),
-                            Erl = filename:join([LocalErtsBin, "erl.ini"]),
-                            rlx_file_utils:copy(DynErl, Erl)
+                            ok
                     end,
 
-                    %% drop yielding_c_fun binary if it exists
-                    %% it is large (1.1MB) and only used at compile time
-                    _ = rlx_file_utils:remove(filename:join([LocalErtsBin, "yielding_c_fun"])),
+                    case Result of
+                        ok ->
+                            %% drop yielding_c_fun binary if it exists
+                            %% it is large (1.1MB) and only used at compile time
+                            _ = rlx_file_utils:remove(filename:join([LocalErtsBin, "yielding_c_fun"])),
 
-                    make_boot_script(State, Release, OutputDir, RelDir)
+                            make_boot_script(State, Release, OutputDir, RelDir);
+                        {error, Reason}->
+                            erlang:error({error, {rlx_file_utils, Reason}})
+                    end
             end
     end.
 
