@@ -163,8 +163,8 @@ run_aux(State, RawArgs) ->
     State5 = case os:getenv("REBAR_CACHE_DIR") of
                 false ->
                     State4;
-                ConfigFile ->
-                    rebar_state:set(State4, global_rebar_dir, ConfigFile)
+                CachePath ->
+                    rebar_state:set(State4, global_rebar_dir, CachePath)
             end,
 
     {ok, Providers} = application:get_env(rebar, providers),
@@ -177,17 +177,27 @@ run_aux(State, RawArgs) ->
     State9 = rebar_state:default(State8, rebar_state:opts(State8)),
 
     {Task, Args} = parse_args(RawArgs),
+    Offline = case lists:member("--offline", Args) of
+                  true ->
+                      %% We store this redundantly in env, because some APIs
+                      %% don't get a state.
+                      os:putenv("REBAR_OFFLINE", "1"),
+                      true;
+                  false ->
+                      os:getenv("REBAR_OFFLINE") =:= "1"
+              end,
+    State10 = rebar_state:set(State9, offline, Offline),
 
-    State10 = rebar_state:code_paths(State9, default, code:get_path()),
+    State11 = rebar_state:code_paths(State10, default, code:get_path()),
 
-    case rebar_core:init_command(rebar_state:command_args(State10, Args), Task) of
-        {ok, State11} ->
+    case rebar_core:init_command(rebar_state:command_args(State11, Args), Task) of
+        {ok, State12} ->
             case rebar_state:get(State11, caller, command_line) of
                 api ->
                     rebar_paths:unset_paths([deps, plugins], State11),
-                    {ok, State11};
+                    {ok, State12};
                 _ ->
-                    {ok, State11}
+                    {ok, State12}
             end;
         Other ->
             Other
@@ -207,9 +217,10 @@ init_config() ->
 
     Config = rebar_config:consult_root(),
     Config1 = rebar_config:merge_locks(Config, rebar_config:consult_lock_file(?LOCK_FILE)),
+    InitState = rebar_state:new(Config1),
 
     %% If $HOME/.config/rebar3/rebar.config exists load and use as global config
-    GlobalConfigFile = rebar_dir:global_config(),
+    GlobalConfigFile = rebar_dir:global_config(InitState),
     State = case filelib:is_regular(GlobalConfigFile) of
                 true ->
                     ?DEBUG("Load global config file ~ts", [GlobalConfigFile]),
@@ -217,10 +228,10 @@ init_config() ->
                     catch
                         _:_ ->
                             ?WARN("Global config ~ts exists but can not be read. Ignoring global config values.", [GlobalConfigFile]),
-                            rebar_state:new(Config1)
+                            InitState
                     end;
                 false ->
-                    rebar_state:new(Config1)
+                    InitState
             end,
 
     %% Determine the location of the rebar executable; important for pulling
@@ -376,9 +387,14 @@ start_and_load_apps(Caller) ->
     ensure_running(crypto, Caller),
     ensure_running(asn1, Caller),
     ensure_running(public_key, Caller),
-    ensure_running(ssl, Caller),
-    ensure_running(inets, Caller),
-    inets:start(httpc, [{profile, rebar}]).
+    case os:getenv("REBAR_OFFLINE") of
+        "1" ->
+            ok;
+        _ ->
+            ensure_running(ssl, Caller),
+            ensure_running(inets, Caller),
+            inets:start(httpc, [{profile, rebar}])
+    end.
 
 %% @doc Make sure a required app is running, or display an error message
 %% and abort if there's a problem.
@@ -402,7 +418,14 @@ ensure_running(App, Caller) ->
 -spec state_from_global_config([term()], file:filename()) -> rebar_state:t().
 state_from_global_config(Config, GlobalConfigFile) ->
     GlobalConfigTerms = rebar_config:consult_file(GlobalConfigFile),
-    GlobalConfig = rebar_state:new(GlobalConfigTerms),
+    GlobalConfigTmp = rebar_state:new(GlobalConfigTerms),
+
+    GlobalConfig = case os:getenv("REBAR_CACHE_DIR") of
+                false ->
+                    GlobalConfigTmp;
+                CachePath ->
+                    rebar_state:set(GlobalConfigTmp, global_rebar_dir, CachePath)
+            end,
 
     %% We don't want to worry about global plugin install state effecting later
     %% usage. So we throw away the global profile state used for plugin install.
