@@ -19,7 +19,7 @@
 %% @doc from the base directory, find all the applications
 %% at the top level and their dependencies based on the configuration
 %% and profile information.
--spec do(rebar_state:t(), [file:filename()]) -> rebar_state:t().
+-spec do(rebar_state:t(), [file:filename()]) -> rebar_state:t() | no_return().
 do(State, LibDirs) ->
     BaseDir = rebar_state:dir(State),
     Dirs = [filename:join(BaseDir, LibDir) || LibDir <- LibDirs],
@@ -64,8 +64,8 @@ do(State, LibDirs) ->
                                 OutDir = filename:join(DepsDir, Name),
                                 AppInfo2 = rebar_app_info:out_dir(AppInfo1, OutDir),
                                 ProjectDeps1 = lists:delete(Name, ProjectDeps),
-                                rebar_state:project_apps(StateAcc1
-                                                        ,rebar_app_info:deps(AppInfo2, ProjectDeps1));
+                                rebar_state:project_apps(StateAcc1,
+                                                         rebar_app_info:deps(AppInfo2, ProjectDeps1));
                             false ->
                                 ?INFO("Ignoring ~ts", [Name]),
                                 StateAcc
