@@ -12,6 +12,7 @@
 -export([eunit_tests/1, eunit_opts/1, eunit_first_files/1]).
 -export([single_application_arg/1, multi_application_arg/1, missing_application_arg/1]).
 -export([single_module_arg/1, multi_module_arg/1, missing_module_arg/1]).
+-export([single_test_arg/1, multi_test_arg/1, missing_test_arg/1]).
 -export([single_suite_arg/1, multi_suite_arg/1, missing_suite_arg/1]).
 -export([single_generator_arg/1, multi_generator_arg/1, missing_generator_arg/1]).
 -export([single_file_arg/1, multi_file_arg/1, missing_file_arg/1]).
@@ -48,6 +49,7 @@ groups() ->
      {cmd_line_args, [], [eunit_tests, eunit_opts, eunit_first_files,
                           single_application_arg, multi_application_arg, missing_application_arg,
                           single_module_arg, multi_module_arg, missing_module_arg,
+                          single_test_arg, multi_test_arg, missing_test_arg,
                           single_suite_arg, multi_suite_arg, missing_suite_arg,
                           single_generator_arg, multi_generator_arg, missing_generator_arg,
                           single_file_arg, multi_file_arg, missing_file_arg,
@@ -365,6 +367,37 @@ missing_module_arg(Config) ->
     Error = {error, {rebar_prv_eunit, {eunit_test_errors, ["Module `missing_app' not found in project."]}}},
     Error = Tests.
 
+%% check that the --test cmd line opt generates the correct test set
+single_test_arg(Config) ->
+    S = ?config(result, Config),
+
+    {ok, Args} = getopt:parse(rebar_prv_eunit:eunit_opts(S), ["--test=module_name:function_name"]),
+    State = rebar_state:command_parsed_args(S, Args),
+
+    {ok, [{test, module_name, function_name}]} = rebar_prv_eunit:prepare_tests(State).
+
+multi_test_arg(Config) ->
+    S = ?config(result, Config),
+
+    {ok, Args} = getopt:parse(rebar_prv_eunit:eunit_opts(S), ["--test=module1:func1+func2,module2:func1;func2"]),
+    State = rebar_state:command_parsed_args(S, Args),
+
+    Generators = [{test, module1, func1},
+                  {test, module1, func2},
+                  {test, module2, func1},
+                  {test, module2, func2}],
+    {ok, Generators} = rebar_prv_eunit:prepare_tests(State).
+
+%% check that an invalid --test cmd line opt generates an error
+missing_test_arg(Config) ->
+    S = ?config(result, Config),
+
+    {ok, Args} = getopt:parse(rebar_prv_eunit:eunit_opts(S), ["--test=missing_module:func1"]),
+    State = rebar_state:command_parsed_args(S, Args),
+
+    Error = {error, {rebar_prv_eunit, {eunit_test_errors, ["Module `missing_module' not found in project."]}}},
+    Error = rebar_prv_eunit:validate_tests(State, rebar_prv_eunit:prepare_tests(State)).
+
 %% check that the --suite cmd line opt generates the correct test set
 single_suite_arg(Config) ->
     AppDir = ?config(apps, Config),
@@ -421,7 +454,7 @@ single_generator_arg(Config) ->
 multi_generator_arg(Config) ->
     S = ?config(result, Config),
 
-    {ok, Args} = getopt:parse(rebar_prv_eunit:eunit_opts(S), ["--generator=module1:func1;func2,module2:func1;func2"]),
+    {ok, Args} = getopt:parse(rebar_prv_eunit:eunit_opts(S), ["--generator=module1:func1+func2,module2:func1;func2"]),
     State = rebar_state:command_parsed_args(S, Args),
 
     Generators = [{generator, module1, func1},
